@@ -26,7 +26,7 @@ print('''
      / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
     /_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
                                                                                                                                                                                         
-        ALACORDER beta 7.4.9.9.9
+        ALACORDER beta 7.4.9.9.9.9.9.9.9
         by Sam Robson   
 
     Alacorder processes case detail PDFs into data tables
